import request from "@/utils/request";
var service_name = "oil-user";
var group_name = "oilCompanyInfo";
export default {
    getByPage(page) {
        // 分页查询
        return request({
            url: `/${service_name}/${group_name}/getByPage`,
            method: "post",
            data: page,
        });
    },
    save(oilCompanyInfo) {
        // 保存
        return request({
            url: `/${service_name}/${group_name}/save`,
            method: "post",
            data: oilCompanyInfo,
        });
    },
    get(id) {
        // 根据id查询
        return request({
            url: `/${service_name}/${group_name}/get/${id}`,
            method: "get",
        });
    },
    update(oilCompanyInfo) {
        // 更新
        return request({
            url: `/${service_name}/${group_name}/update`,
            method: "put",
            data: oilCompanyInfo,
        });
    },
    exportExcel(page) {
        // 导出
        return request({
            url: `/oil-finance/oilOrderInfoExcel/exportExcel`,
            method: "post",
            // notEncrypt: true,
            data: page,
            responseType: "blob",
        });
    },
    deleteById(id) {
        // 根据id删除
        return request({
            url: `/${service_name}/${group_name}/delete`,
            method: "put",
            data: { id: id },
        });
    },

    getAllCompany() {
        // 获取全部可用企业
        return request({
            url: `/${service_name}/${group_name}/getAllCompany`,
            method: "get",
        });
    },
    getLikeByName(oilCompanyInfo) {
        // 根据企业名称模糊搜索
        return request({
            url: `/${service_name}/${group_name}/getLikeByName`,
            method: "post",
            data: oilCompanyInfo,
        });
    },
    getRelationSite(oilCompanyInfo) {
        // 根据企业名称模糊搜索
        return request({
            url: `/oil-site/oilSiteInfo/getRelationSite`,
            method: "post",
            data: oilCompanyInfo,
        });
    },
    getByEntity(oilCompanyInfo) {
        // 模糊查询
        return request({
            url: `/${service_name}/${group_name}/getByEntity`,
            method: "post",
            data: oilCompanyInfo,
        });
    },
    getSubCompany(oilCompanyInfo) {
        // 查询子公司或者同级公司和总公司
        return request({
            url: `/${service_name}/${group_name}/getSubCompany`,
            method: "post",
            data: oilCompanyInfo,
        });
    },
    getLikeByNameOrId(oilCompanyInfo) {
        // 根据企业名称模糊搜索
        return request({
            url: `/${service_name}/${group_name}/getLikeByNameOrId`,
            method: "post",
            data: oilCompanyInfo,
        });
    },
    getLikeByNameMainCompany(oilCompanyInfo) {
        // 根据企业名称模糊搜索
        return request({
            url: `/${service_name}/${group_name}/getLikeByNameMainCompany`,
            method: "post",
            data: oilCompanyInfo,
        });
    },
    getLikeByNameAndId(oilCompanyInfo) {
        // 根据企业名称和企业编号,模糊搜索不等于当前公司的其他公司
        return request({
            url: `/${service_name}/${group_name}/getLikeByNameAndId`,
            method: "post",
            data: oilCompanyInfo,
        });
    },
    updateBatchEnable(data) {
        // 批量修改启用禁用状态
        return request({
            url: `/${service_name}/${group_name}/updateBatchEnable`,
            method: "post",
            data,
        });
    },
    openShareDistribute(data) {
        // 批量修改启用禁用状态
        return request({
            url: `/${service_name}/${group_name}/openShareDistribute`,
            method: "post",
            data,
        });
    },
    audit(data) {
        // 审核
        return request({
            url: `/${service_name}/${group_name}/audit`,
            method: "post",
            data,
        });
    },
    getLikeByNameSuccess(data) {
        // 根据企业名称模糊搜索可用企业
        return request({
            url: `/${service_name}/${group_name}/getLikeByNameSuccess`,
            method: "post",
            data,
        });
    },
    getByUserId(id) {
        // 根据用户id查询
        return request({
            url: `/${service_name}/${group_name}/getByUserId/${id}`,
            method: "get",
        });
    },
    getByCustomerId(id) {
        // 查询用户关联调度企业
        return request({
            url: `/${service_name}/oilCustomerDispatchRelation/getByCustomerId/${id}`,
            method: "get",
        });
    },
    getRefineryByCustomerId(id) {
        // 查询用户关联油批企业
        return request({
            url: `/${service_name}/oilCustomerDispatchRelation/getRefineryByCustomerId/${id}`,
            method: "get",
        });
    },
    getByRole(data, userId) {
        // 根据角色获取对应的企业
        return request({
            url: `/${service_name}/${group_name}/getByRole/${userId}`,
            method: "post",
            data,
        });
    },
    getLike(value) {
        // 模糊搜索企业
        return request({
            url: `/${service_name}/${group_name}/getLike/${value}`,
            method: "get",
        });
    },
    getCompanyListCustomer(id) {
        // 获取发起公司列表
        return request({
            url: `/${service_name}/${group_name}/getCompanyListCustomer`,
            method: "get",
        });
    },
    getCompanyList(id) {
        return request({
            url: `/${service_name}/${group_name}/getCompanyList`,
            method: "get",
        });
    },
    getSubCompanyListCustomer(id) {
        // 获取接收公司列表
        return request({
            url: `/${service_name}/${group_name}/getSubCompanyListCustomer`,
            method: "get",
        });
    },
    // 获取企业列表（远程搜索）
    getCompanyNames(name) {
        return request({
            url: `/${service_name}/${group_name}/getCompanyNames/${name}`,
            method: "get",
        });
    },
    // 获取企业列表（远程搜索）
    // getLikeByNameMainCompany(data) {
    //     return request({
    //         url: `/${service_name}/${group_name}/getLikeByNameMainCompany`,
    //         method: "post",
    //         data,
    //     });
    // },
    // 企业用户手机号验证
    validatePhoneUserRolePermissions(data) {
        return request({
            url: `/${service_name}/oilCustomerCompanyRelation/validatePhoneUserRolePermissions`,
            method: "post",
            data,
        });
    },
    findByUserId(data) {
        return request({
            url: `/oil-user/etcUserCustomer/findByUserId`,
            method: "get",
            params: data,
        });
    },
    findAllCustomerList(data) {
        return request({
            url: `/lsm-etc-service/etcCustomer/findAllCustomerList`,
            method: "get",
            params: data,
        });
    },
    // deleteById(data) {
    //     return request({
    //         url: `/oil-user/etcUserCustomer/deleteById`,
    //         method: "get",
    //         params: data,
    //     });
    // },
    getByCompanyId(companyId) {
        return request({
            url: `/oil-finance/oilCompanyBankCard/getByCompanyId/${companyId}`,
            method: "get",
        });
    },
    saveBatchCompanyRelationBank(data) {
        return request({
            url: `/oil-finance/oilCompanyBankCard/saveBatchCompanyRelationBank`,
            method: "post",
            data,
        });
    },
    countByCompanyId(id) {
        return request({
            url: `/oil-site/oilCompanySiteInfoRelation/countByCompanyId/${id}`,
            method: "get",
        });
    },
    export(id) {
        return request({
            url: `/oil-site/oilCompanySiteInfoRelation/export/${id}`,
            method: "get",
            responseType: "blob",
        });
    },
    importSave(data) {
        return request({
            url: `/oil-site/oilCompanySiteInfoRelation/importSave`,
            method: "post",
            data,
        });
    },
};
